@@ -77,14 +77,15 @@ knitr::kable(
 )
 
 ## ----fakegrouplines, echo = TRUE----------------------------------------------
-#  utm <- '+proj=utm +zone=21 ellps=WGS84'
+#  utm <- '+init=epsg:32736'
+#  
 #  group_times(DT = DT, datetime = 'datetime', threshold = '1 day')
 #  group_lines(DT, threshold = 50, projection = utm,
 #              id = 'ID', coords = c('X', 'Y'),
 #              timegroup = 'timegroup', sortBy = 'datetime')
 
 ## ----grouplines, eval = TRUE--------------------------------------------------
-utm <- '+proj=utm +zone=21 ellps=WGS84'
+utm <- '+init=epsg:32736'
 
 DT <- group_times(DT = DT, datetime = 'datetime', 
                 threshold = '1 day')
@@ -97,7 +98,7 @@ knitr::kable(
 )
 
 ## ----fakegrouppolys, echo = TRUE----------------------------------------------
-#  utm <- '+proj=utm +zone=21 ellps=WGS84'
+#  utm <- '+init=epsg:32736'
 #  group_times(DT = DT, datetime = 'datetime', threshold = '8 days')
 #  group_polys(DT = DT, area = TRUE, hrType = 'mcp',
 #             hrParams = list('percent' = 95),
@@ -105,7 +106,7 @@ knitr::kable(
 #             coords = c('X', 'Y'), id = 'ID')
 
 ## ----grouppolys, eval = TRUE--------------------------------------------------
-utm <- '+proj=utm +zone=21 ellps=WGS84'
+utm <- '+init=epsg:32736'
 DT <- group_times(DT = DT, datetime = 'datetime', 
                 threshold = '8 days')
 knitr::kable(
